from datetime import datetime
from typing import Any

from pydantic import BaseModel, Field

from omnibase_core.models.core.model_base_input_state import ModelBaseInputState
from omnibase_core.models.core.model_base_output_state import ModelBaseOutputState

"""
Base state models for ONEX.

These are the fundamental models that all input/output states inherit from.
"""
