"""Mixin-related models for ONEX framework."""

from omnibase_core.models.mixins.model_service_registry_entry import (
    ModelServiceRegistryEntry,
)

__all__ = [
    "ModelServiceRegistryEntry",
]
