import json

"""
ModelIntrospectionNodeInfo configuration.
"""


class ModelIntrospectionNodeInfoConfig:
    json_schema_extra = {
        "example": {
            "node_name": "tool_example",
            "node_version": "1.0.0",
            "description": "Example tool",
            "author": "ONEX System",
            "tool_type": "generation",
            "created_at": "2024-01-01T00:00:00",
        },
    }
