"""
CLI Operations Models

Models for command-line interface operations, execution, and results.
"""

from typing import TypedDict

from omnibase_core.types import (
    TypedDictCliInputDict,
    TypedDictDebugInfoData,
    TypedDictPerformanceMetricData,
    TypedDictTraceInfoData,
)

from .model_cli_action import ModelCliAction
from .model_cli_advanced_params import ModelCliAdvancedParams
from .model_cli_command_option import ModelCliCommandOption
from .model_cli_debug_info import ModelCliDebugInfo
from .model_cli_execution import ModelCliExecution
from .model_cli_execution_context import ModelCliExecutionContext
from .model_cli_execution_input_data import ModelCliExecutionInputData
from .model_cli_execution_result import ModelCliExecutionResult
from .model_cli_execution_summary import ModelCliExecutionSummary
from .model_cli_node_execution_input import ModelCliNodeExecutionInput
from .model_cli_output_data import ModelCliOutputData
from .model_cli_result import ModelCliResult
from .model_cli_result_formatter import ModelCliResultFormatter
from .model_output_format_options import ModelOutputFormatOptions

__all__ = [
    "ModelCliAction",
    "ModelCliAdvancedParams",
    "ModelCliCommandOption",
    "ModelCliDebugInfo",
    "ModelCliExecution",
    "ModelCliExecutionContext",
    "ModelCliExecutionInputData",
    "ModelCliExecutionResult",
    "ModelCliExecutionSummary",
    "ModelCliNodeExecutionInput",
    "ModelCliOutputData",
    "ModelCliResult",
    "ModelCliResultFormatter",
    "ModelOutputFormatOptions",
    "TypedDictCliInputDict",
    "TypedDictDebugInfoData",
    "TypedDictPerformanceMetricData",
    "TypedDictTraceInfoData",
]
