from .model_action import ModelAction
from .model_state import ModelState as ImportedModelState

# Compatibility aliases
ActionModel = ModelAction
StateModel = ImportedModelState

# === OmniNode:Metadata ===
# author: OmniNode Team
# copyright: OmniNode.ai
# created_at: '2025-05-28T13:24:08.047863'
# description: Stamped by ToolPython
# entrypoint: python://model_reducer
# hash: db3311c6cfb2303fea2bdd33b9b1e86e4b7fd704e72ba9c216234e1ecb886357
# last_modified_at: '2025-05-29T14:13:58.919275+00:00'
# lifecycle: active
# meta_type: tool
# metadata_version: 0.1.0
# name: model_reducer.py
# namespace: python://omnibase.model.model_reducer
# owner: OmniNode Team
# protocol_version: 0.1.0
# runtime_language_hint: python>=3.11
# schema_version: 0.1.0
# state_contract: state_contract://default
# tools: {}
# uuid: bad313b8-30cb-45ad-9141-ea8d43fe0a91
# version: 1.0.0
# === /OmniNode:Metadata ===


from pydantic import BaseModel


class ModelState(BaseModel):
    # Placeholder for ONEX state fields

    # Placeholder for ONEX action fields
    pass
