from enum import Enum


class EnumAuthenticationMethod(str, Enum):
    """Authentication methods supported."""

    NONE = "none"
    BASIC = "basic"
    TOKEN = "token"
    CERTIFICATE = "certificate"
    MULTI_FACTOR = "multi_factor"
