"""Configuration for ModelSecureEventEnvelope."""

from datetime import datetime

from pydantic import ConfigDict


class ModelSecureEventEnvelopeConfig:
    """Configuration for ModelSecureEventEnvelope."""

    model_config = ConfigDict()
