#!/usr/bin/env python3
"""
Model Configuration for ONEX Performance Metrics - ONEX Standards Compliant.

Strongly-typed configuration class for ONEX performance metrics.
"""


class ModelConfig:
    """Pydantic configuration for ONEX performance metrics."""

    frozen = True
