#!/usr/bin/env python3
"""
Model Configuration for CLI Tool Execution Input - ONEX Standards Compliant.

Strongly-typed configuration class for CLI tool execution input.
"""

from datetime import datetime


class ModelConfig:
    """Pydantic configuration for CLI tool execution input."""
